pub struct BiconnectedComponents {
pub count: usize,
pub tree_edges: Vec<Vec<EdgeId>>,
pub component_edges: Vec<Vec<EdgeId>>,
pub components: Vec<Vec<VertexId>>,
pub articulation_points: Vec<VertexId>,
}Expand description
The biconnected components of a graph, see
Graph::biconnected_components.
All the lists are indexed by component id, in 0..count.
Fields
count: usizeThe number of biconnected components.
tree_edges: Vec<Vec<EdgeId>>For each component, the edges of one of its spanning trees.
component_edges: Vec<Vec<EdgeId>>For each component, all of its edges. Every non-loop edge of the graph belongs to exactly one component.
components: Vec<Vec<VertexId>>For each component, its vertices. A vertex may belong to several components (exactly when it is an articulation point) and isolated vertices belong to none.
articulation_points: Vec<VertexId>The articulation points (cut vertices) of the graph.