pub struct BondPercolation {
pub giant_size: Vec<usize>,
pub vertex_count: Vec<usize>,
}Expand description
A bond (edge) percolation curve, see Graph::bond_percolation and
edgelist_percolation.
Fields
giant_size: Vec<usize>giant_size[i] is the size of the largest component after the first
i + 1 edges have been added.
vertex_count: Vec<usize>vertex_count[i] is the number of vertices having at least one
incident edge after the first i + 1 edges have been added.