pub struct CohesiveBlocks {
pub blocks: Vec<Vec<VertexId>>,
pub cohesion: Vec<usize>,
pub parent: Vec<Option<usize>>,
pub block_tree: Graph,
}Expand description
The cohesive block hierarchy of a graph, see Graph::cohesive_blocks.
Block 0 is always the whole graph; the lists are indexed by block id.
Fields
blocks: Vec<Vec<VertexId>>The vertex ids of each block.
cohesion: Vec<usize>The cohesion (vertex connectivity) of each block.
parent: Vec<Option<usize>>The parent block of each block in the hierarchy (None for the root).
block_tree: GraphThe hierarchy as a (directed) tree graph: vertex i is block i, and
there is an edge from each block to each of its children.
Implementations
Sourceimpl CohesiveBlocks
impl CohesiveBlocks
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Whether there are no blocks. Results of Graph::cohesive_blocks
always contain at least the root block (even for the null graph,
whose root block is empty), so this is false for them.
Sourcepub fn max_cohesion_of(&self, v: VertexId) -> Option<usize>
pub fn max_cohesion_of(&self, v: VertexId) -> Option<usize>
The largest cohesion of a block containing vertex v (its
“embeddedness”), or None if no block contains it.