pub struct ConnectedComponents {
pub membership: Vec<VertexId>,
pub sizes: Vec<usize>,
pub count: usize,
}Expand description
The connected components of a graph, see Graph::connected_components.
Fields
membership: Vec<VertexId>membership[v] is the id (in 0..count) of the component of vertex v.
sizes: Vec<usize>sizes[c] is the number of vertices in component c.
count: usizeThe number of components.
Implementations
Sourceimpl ConnectedComponents
impl ConnectedComponents
Sourcepub fn members(&self, c: usize) -> Vec<VertexId> ⓘ
pub fn members(&self, c: usize) -> Vec<VertexId> ⓘ
The vertices of component c, in increasing id order (empty if c
is out of range).
Sourcepub fn groups(&self) -> Vec<Vec<VertexId>>
pub fn groups(&self) -> Vec<Vec<VertexId>>
All the components as vertex lists, indexed by component id.
Sourcepub fn largest(&self) -> Option<usize>
pub fn largest(&self) -> Option<usize>
Id of a largest (“giant”) component, the first one on ties; None
for the null graph.
Sourcepub fn same_component(&self, u: VertexId, v: VertexId) -> bool
pub fn same_component(&self, u: VertexId, v: VertexId) -> bool
Whether vertices u and v lie in the same component (false for
out-of-range ids).