pub struct Reachability {
pub membership: Vec<VertexId>,
pub sizes: Vec<usize>,
pub count: usize,
pub reach: Vec<Vec<bool>>,
}Expand description
Reachability information, see Graph::reachability.
Vertices in the same strongly connected component reach exactly the same vertices, so the reachable sets are stored once per component.
Fields
membership: Vec<VertexId>membership[v] is the id of the (strongly, for directed graphs with
Out/In modes) connected component of v.
sizes: Vec<usize>sizes[c] is the number of vertices of component c.
count: usizeThe number of components.
reach: Vec<Vec<bool>>reach[c][v] is true when vertex v is reachable from the vertices
of component c (every vertex reaches itself).
Implementations
Sourceimpl Reachability
impl Reachability