pub struct SitePercolation {
pub giant_size: Vec<usize>,
pub edge_count: Vec<usize>,
}Expand description
A site (vertex) percolation curve, see Graph::site_percolation.
Fields
giant_size: Vec<usize>giant_size[i] is the size of the largest component after the first
i + 1 vertices have been added.
edge_count: Vec<usize>edge_count[i] is the number of edges among the first i + 1 added
vertices.